#------------------------------------------------------------------------------
#
#   Flappy Butterfly - Main
#
#------------------------------------------------------------------------------

from albow.resource import resource_path, get_image
from albow.music import change_music
from humerus.options import Options

class FBOptions(Options):

	frame_rate_option = 20
	screen_size_option = (1008, 672)

options = FBOptions()

from pygame import Color, Rect
from pygame.locals import K_UP, K_DOWN
from albow.screen import Screen
from albow.controls import Label
from albow.resource import get_font, get_sound
from albow.dialogs import alert
from humerus.hgame import HGame
from humerus.hshell import HShell
from humerus.main_commands import MainCommandScreen
from scenes import scene_list
from player import Butterfly
from play_screen import FBPlayScreen

#------------------------------------------------------------------------------

class FBState:

	def __init__(self):
		self.player = Butterfly()
		self.mishaps = 0
		self.princess_found = False
		self.is_completed = False
		self.scene_index = 0
		self.start_scene()
	
	def inc_mishaps(self):
		self.mishaps += 1
	
	def start_scene(self):
		self.scene = scene_list[self.scene_index](self)
		self.player.position = self.scene.start_position
		#self.player.flying = True
	
	def next_scene(self):
		i = self.scene_index + 1
		if i < len(scene_list):
			self.scene_index = i
			self.start_scene()
		else:
			self.is_completed = True
	
	def begin_frame(self):
		scene = self.scene
		player = self.player
		player.begin_frame(scene)
		for ent in scene.entities:
			ent.begin_frame(self)
		rp = player.collision_rect
		for target, rect in scene.triggers:
			if rp.colliderect(rect):
				target.trigger(self)
		if player.position[0] > scene.width:
			self.next_scene()
	
	def draw(self, surf):
		scene = self.scene
		scene.draw_back(surf)
		self.player.draw(surf)
		scene.draw_front(surf)
	
	def key_down(self, e):
		k = e.key
		if k == K_UP:
			self.player.control_state = 1
		elif k == K_DOWN:
			self.player.control_state = -1
		else:
			return 'pass'

	def key_up(self, e):
		k = e.key
		s = self.player.control_state
		if k == K_UP:
			if s == 1:
				self.player.control_state = 0
		elif k == K_DOWN:
			if s == -1:
				self.player.control_state = 0
		else:
			return 'pass'

#------------------------------------------------------------------------------

class FBGame(HGame):

	def new_state(self):
		return FBState()
	
	def game_is_completed(self):
		state = self.state
		if state.is_completed:
			if state.mishaps == 0:
				return 2
			else:
				return 1
		else:
			return 0
	
	def begin_frame(self):
		self.state.begin_frame()

#------------------------------------------------------------------------------

class FBMainCommandScreen(MainCommandScreen):

	#bg_color = Color("skyblue")
	bg_image = get_image("title_screen.png")

	def __init__(self, shell):
		MainCommandScreen.__init__(self, shell, with_menu = True)
	
# 	def draw(self, surf):
# 		surf.blit(self.bg_image, (0, 0)
# 		super().draw(surf)
	
	def include_command(self, cmd):
		return cmd in [
			'about', 'new_game', 'resume_game', 'quit']
	
	def enter_screen(self):
		change_music(resource_path("music", "Mermaid_Butterfly.ogg"), repeat = True)

#------------------------------------------------------------------------------

help_text = \
"""Up arrow to take off or climb.\n
Let go to glide.\n
Down arrow to descend faster.\n
You lose a point if you cause a mishap.\n
Reach the end without any mishaps to win."""

class FBHelpScreen(Screen):

	bg_color = (255, 255, 255)

	def __init__(self, shell):
		Screen.__init__(self, shell)
		help = Label(help_text, font = get_font(18, "Vera.ttf"))
		self.add_centered(help)

#------------------------------------------------------------------------------

class FBShell(HShell):

	game_title = "Flappy Butterfly"
	
	def __init__(self, game, options):
		HShell.__init__(self, game, options)
		self.about_screen = FBHelpScreen(self)
		self.main_menu_screen = FBMainCommandScreen(self)
		self.play_screen = FBPlayScreen(self)
	
# 	def game_completed(self, result):
# 		if result == 2:
# 			alert("And they lived happily for the rest of the day.")
# 		super().game_completed(result)

#------------------------------------------------------------------------------

game = FBGame()
shell = FBShell(game, options)
shell.run()
