#------------------------------------------------------------------------------
#
#   Flappy Butterfly - Playing Screen
#
#------------------------------------------------------------------------------

from pygame import Color
from albow.controls import Label, ValueDisplay
from albow.layout import Row
from albow.references import Ref
from albow.resource import get_font
from albow.resource import resource_path
from albow.music import change_music
from albow.dialogs import alert
from albow.screen import Screen

class FBPlayScreen(Screen):

	def __init__(self, shell):
		super().__init__(shell)
		sbfont = get_font(24, "VeraBd.ttf")
		status_bar = Row([
			Label("Mishaps:", font = sbfont),
			ValueDisplay(font = sbfont, ref = Ref(shell.game).state.mishaps),
		], bg_color = Color("bisque"))
		status_bar.width = 1008
		status_bar.bottomleft = self.rect.bottomleft
		self.add(status_bar)

	def draw(self, surf):
		self.shell.game.state.draw(surf)

	def begin_frame(self):
		self.shell.game.state.begin_frame()
	
	def key_down(self, e):
		if self.shell.game.state.key_down(e) == 'pass':
			return super().key_down(e)

	def key_up(self, e):
		if self.shell.game.state.key_up(e) == 'pass':
			return super().key_up(e)

	def enter_screen(self):
		change_music(resource_path("music", "Finding_The_Butterfly.ogg"), repeat = True)

	def leave_screen(self):
		state = self.shell.game.state
		if state.princess_found:
			state.is_completed = True
			alert("And they lived happily for the rest of the day.")
