#------------------------------------------------------------------------------
#
#   Flappy Butterfly - Player
#
#------------------------------------------------------------------------------

from pygame import Rect
from albow.resource import get_image
from albow.image_array import get_image_array
from collision import find_collision_mask, CM_UP, CM_DOWN, CM_RIGHT

body_image = get_image("body.png")
wing_images = get_image_array("wings.png", (2, 6))

forward_speed = 5
ascent_rate = -5
glide_rate = 1
descent_rate = 5

class Butterfly:

	collision_rect_heights = [46, 44, 40, 34, 26, 16]

	def __init__(self):
		self.position = (0, 0)
		self.phase = 0
		self.flying = False
		self.control_state = 0
	
	def is_flapping(self):
		return self.flying and self.control_state == 1

	def begin_frame(self, scene):
		self.setup_image()
		r = self.collision_rect
		x, y = self.position
		s = self.control_state
		dx = forward_speed
		if s == 1:
			dy = ascent_rate
		elif s == 0:
			dy = glide_rate
		else:
			dy = descent_rate
		flying = True
		cm = find_collision_mask(r, scene.obstacles)
		if y <= 20:
			cm |= CM_UP
		if y >= scene.height:
			cm |= CM_DOWN
		if dx > 0 and cm & CM_RIGHT:
			dx = 0
		if dy < 0 and cm & CM_UP:
			dy = 0
		elif dy > 0 and cm & CM_DOWN:
			dx = 0
			dy = 0
			flying = False
		if flying:
			if s == 1:
				self.advance_phase()
			elif s == 0:
				self.phase = 5
			else:
				self.phase = 1
		else:
			self.phase = 0
		x += dx
		y += dy
		self.position = (x, y)
		self.flying = flying

	def setup_image(self):
		p = self.position
		i = self.phase
		if i >= 12:
			i = 23 - i
		if i < 6:
			r = 0
			c = i
		else:
			r = 1
			c = 11 - i
		self.image_row = r
		self.image_col = c
		cr = Rect(0, 0, 60, self.collision_rect_heights[c])
		if r == 0:
			cr.midbottom = self.position
		else:
			cr.midtop = self.position
		self.collision_rect = cr

	def advance_phase(self):
		self.phase = (self.phase + 1) % 24

	def draw(self, surf):
		p = self.position
		dst = body_image.get_rect()
		dst.center = p
		surf.blit(body_image, dst.topleft)
		dst = wing_images.get_rect()
		r = self.image_row
		c = self.image_col
		if r == 0:
			dst.midbottom = p
		else:
			dst.midtop = p
		surf.blit(wing_images[r, c], dst.topleft)
