#------------------------------------------------------------------------------
#
#   Flappy Butterfly - Scene
#
#------------------------------------------------------------------------------

from albow.resource import get_image, get_sound

class Scene:

	width = 1008
	height = 640
	gravity = 1
	obstacles = []
	entities = []
	triggers = []

	def __init__(self, state):
		self.bg_image = get_image(self.background)
	
	def draw_back(self, surf):
		surf.blit(self.bg_image, (0, 0))
		for ent in self.entities:
			ent.draw_back(surf)
	
	def draw_front(self, surf):
		for ent in self.entities:
			ent.draw_front(surf)

#------------------------------------------------------------------------------

oop = get_sound("oop.ogg")
oop.set_volume(0.25)

class Entity:
	
	def trigger(self, state):
		pass
	
	def mishap_sound(self):
		#oop.play()
		pass

	def draw_back(self, surf):
		pass

	def draw_front(self, surf):
		pass

	def begin_frame(self, state):
		pass

#------------------------------------------------------------------------------

class Fixture(Entity):

	back_image = None
	front_image = None

	def __init__(self, left, top, back = None, front = None):
		self.topleft = (left, top)
		if back:
			self.back_image = get_image(back)
		if front:
			self.front_image = get_image(front)
		
	def draw_back(self, surf):
		self.draw_image(surf, self.back_image)

	def draw_front(self, surf):
		self.draw_image(surf, self.front_image)

	def draw_image(self, surf, image):
		if image:
			surf.blit(image, self.topleft)
