#------------------------------------------------------------------------------
#
#   Flappy Butterfly - Tyre Scene
#
#------------------------------------------------------------------------------

from pygame import Rect
from albow.resource import get_image
from scene import Scene, Entity

#------------------------------------------------------------------------------

class Tyre(Entity):

	back_image = get_image("tyre-back.png")
	front_image = get_image("tyre-front.png")
	
	def __init__(self, x, y):
		self.position = x, y
		self.vy = 0
		self.state = 0
	
	def draw_back(self, surf):
		img = self.back_image
		r = img.get_rect()
		r.topleft = self.position
		surf.blit(img, r)
	
	def draw_front(self, surf):
		x, y = self.position
		img = self.front_image
		r = img.get_rect()
		r.x = x + 45
		r.y = y + 27
		surf.blit(img, r)
	
	def begin_frame(self, state):
		if self.state == 1:
			scene = state.scene
			x, y = self.position
			y += self.vy
			self.position = x, y
			self.vy += scene.gravity
			if y + 214 >= scene.height:
				self.state = 2
				state.inc_mishaps()
	
	def trigger(self, state):
		if self.state == 0:
			self.state = 1
			self.mishap_sound()

#------------------------------------------------------------------------------

class Scene1(Scene):

	background = "scene1.png"

	obstacles = [
		Rect(23, 367, 157, 248),
		Rect(380, 43, 292, 167), Rect(582, 0, 288, 138), Rect(869, 54, 138, 184),
	]
	
	start_position = (105, 367)

	def __init__(self, state):
		Scene.__init__(self, state)
		tyre = Tyre(829, 360)
		self.entities = [tyre]
		self.triggers = [
			(tyre, Rect(888, 238, 15, 122)),
			(tyre, Rect(829, 360, 131, 65)),
			(tyre, Rect(829, 541, 131, 33)),
		]

