#------------------------------------------------------------------------------
#
#   Flappy Butterfly - Shed Scene
#
#------------------------------------------------------------------------------

from pygame import Rect
from pygame.transform import rotozoom
from albow.resource import get_image, get_sound
from scene import Scene, Entity, Fixture
from vector_algebra import vadd, vrotate

#------------------------------------------------------------------------------

class Rake(Entity):

	upright_image = get_image("rake-upright.png")
	fallen_image = get_image("rake-fallen.png")
	pivot_to_centre = (-10, -168) # Pivot to centre of upright image
	pivot_to_centre_fallen = (175, -75)
	angular_acceleration = 0.1
	max_angle = 85
	
	def __init__(self, x0, y0, victim):
		self.pivot = (x0, y0)
		self.victim = victim
		self.state = 0
		self.angle = 0
		self.angular_velocity = 0
	
	def draw_back(self, surf):
		s = self.state
		if s == 0:
			img = self.upright_image
			p = self.pivot_to_centre
		elif s == 1:
			a = self.angle
			img = rotozoom(self.upright_image, -a, 1.0)
			p = vrotate(self.pivot_to_centre, a)
		else:
			img = self.fallen_image
			p = self.pivot_to_centre_fallen
		r = img.get_rect()
		r.center = vadd(p, self.pivot)
		surf.blit(img, r.topleft)
	
	def trigger(self, state):
		if self.state == 0:
			self.state = 1
			self.mishap_sound()
	
	def begin_frame(self, state):
		if self.state == 1:
			self.angle += self.angular_velocity
			self.angular_velocity += self.angular_acceleration
			if self.angle >= self.max_angle:
				self.state = 2
				self.victim.trigger(state)

#------------------------------------------------------------------------------

class Flowerpot(Entity):

	intact_image = get_image("flowerpot-intact.png")
	broken_image = get_image("flowerpot-broken.png")
	broken_offset = (-28, 156)
	break_sound = get_sound("flowerpot-break.ogg")
	
	def __init__(self, x, y):
		self.position = (x, y)
		self.state = 0
	
	def draw_back(self, surf):
		s = self.state
		if s == 0:
			img = self.intact_image
			p = self.position
		else:
			img = self.broken_image
			p = vadd(self.position, self.broken_offset)
		r = img.get_rect()
		r.topleft = p
		surf.blit(img, p)
	
	def trigger(self, state):
		self.state = 1
		self.break_sound.play()
	
	def begin_frame(self, state):
		if self.state == 1:
			state.inc_mishaps()
			self.state = 2

#------------------------------------------------------------------------------

class Scene2(Scene):

	background = "scene2.png"

	start_position = (0, 479)

	def __init__(self, state):
		Scene.__init__(self, state)
		flowerpot = Flowerpot(737, 361)
		rake = Rake(506, 607, flowerpot)
		self.obstacles = [
			Rect(756, 0, 252, 125),
			Rect(918, 125, 88, 110),
			Rect(918, 471, 88, 168),
		]
		self.entities = [
			rake,
			flowerpot,
			Fixture(844, 184, front = "scene2-window.png"),
		]
		self.triggers = [
			(rake, Rect(420, 273, 154, 30)),
			(rake, Rect(476, 301, 30, 307)),
		]
