#------------------------------------------------------------------------------
#
#   Flappy Butterfly - Final Scene
#
#------------------------------------------------------------------------------

from pygame import Rect
from pygame.transform import rotozoom
from albow.resource import get_image, get_sound
from albow.image_array import get_image_array
from albow.dialogs import alert
from scene import Scene, Entity, Fixture
from vector_algebra import vadd, vrotate

#------------------------------------------------------------------------------

class Princess(Fixture):

	def __init__(self, heart):
		Fixture.__init__(self, 910, 345, "princess.png")
		self.heart = heart
	
	def trigger(self, state):
		state.princess_found = True
		self.heart.state = 1

class Note(Fixture):

	def __init__(self):
		Fixture.__init__(self, 791, 303, "note.png")
		self.state = 0
		
	def trigger(self, state):
		if self.state == 0:
			self.state = 1
			alert("Sorry, the princess is in another garden. "
				"She says she'll come back if you're less clumsy next time.")
			state.is_completed = True

class Heart(Fixture):

	def __init__(self):
		Fixture.__init__(self, 876, 269, "heart.png")
		self.state = 0
		self.timeout = 200
	
	def draw_back(self, surf):
		if self.state == 1:
			super().draw_back(surf)
	
	def begin_frame(self, state):
		if self.state == 1:
			if self.timeout > 0:
				self.timeout -= 1
			else:
				self.state = 2
				state.is_completed = True

#------------------------------------------------------------------------------

class Scene4(Scene):

	background = "scene4.png"
	
	start_position = (0, 285)
	
	obstacles = [
		Rect(910, 0, 98, 640),
		Rect(845, 400, 135, 240),
	]
	
	def __init__(self, state):
		super().__init__(state)
		heart = Heart()
		if state.mishaps == 0:
			end_entity = Princess(heart)
			end_trigger_rect = Rect(880, 345, 100, 55)
		else:
			end_entity = Note()
			end_trigger_rect = Rect(791, 303, 80, 113)
		self.entities = [
			end_entity,
			heart,
		]
		self.triggers = [(end_entity, end_trigger_rect)]

